.. scllm documentation master file, created by
   sphinx-quickstart on Sun Mar  2 13:59:58 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scllm's documentation!
==================================================

.. toctree::
   :hidden:
   :caption: Tutorials:

   notebooks/cell_types
   notebooks/factor_analysis
   notebooks/nmf


.. toctree::
   :hidden:
   :caption: API Reference:

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`